.. _other-implementations:

Other Implementations
*********************

* `mafintosh/merkle-tree-stream`_
* `datrs/merkle-tree-stream`_
* `datcxx/merkle-tree-stream`_

.. _mafintosh/merkle-tree-stream: https://github.com/mafintosh/merkle-tree-stream
.. _datrs/merkle-tree-stream: https://github.com/datrs/merkle-tree-stream
.. _datcxx/merkle-tree-stream: https://github.com/datcxx/merkle-tree-stream
